@@ -21,12 +21,12 @@ class FlatpageFallbackMiddleware(object):
 
 def flatpage(request):
     
-    rows = request.db.view(settings.COUCHDB_FLATPAGES, key = request.path, include_docs = True).rows
+    rows = request.db.view(settings.COUCHDB_FLATPAGES, key=request.path, include_docs=True, limit=1).rows
     if rows:
         row = rows[0]
-
-
-        return render_to_response('static.html', {'doc': row.doc}, RequestContext(request))
+        
+        
+        return render_to_response(row.doc.get('template', 'static.html'), {'doc': row.doc}, RequestContext(request))
     else:
         raise Http404('Page not found')
     
